#
# spec file for package google-startup-scripts
#
# Copyright (c) 2016 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           google-startup-scripts
Version:        1.3.2
Release:        3.2
Summary:        GCE start up tools
License:        Apache-2.0
Group:          System/Daemons
Url:            https://github.com/GoogleCloudPlatform/compute-image-packages
Source0:        %{name}-%{version}.tar.bz2
Source1:        google.suse
Source2:        google-startup-scripts.suse
Patch0:         google-startup-scripts_disable_console_log.diff
Patch1:         regenhostkey_usetmpdir.diff
%if 0%{?suse_version} > 1140
BuildRequires:  systemd
BuildRequires:  pkgconfig(udev)
%endif
%{?systemd_requires}
%if 0%{?suse_version} < 1140
Requires:       insserv
Requires:       sysvinit
%endif
Requires:       rsyslog
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildArch:      noarch

%description
Google Startup Scripts - Scripts and configuration files that setup a Linux-based image to work smoothly with GCE.

%prep
%setup -q
%patch0 -p1
%patch1 -p2

%build

%install
%{__mkdir} -p %{buildroot}/%{_sysconfdir}
%{__mkdir} -p %{buildroot}/usr
cp -r etc/rsyslog.d %{buildroot}/%{_sysconfdir}
cp -r etc/sysctl.d %{buildroot}/%{_sysconfdir}
cp -r usr/share %{buildroot}/usr
%if 0%{?suse_version} > 1140
    %{__mkdir} -p %{buildroot}/%{_unitdir}
    %{__mkdir} -p %{buildroot}/%{_unitdir}/../system-preset
    %{__mkdir} -p %{buildroot}/%{_sbindir}
    cp usr/lib/systemd/system/* %{buildroot}/%{_unitdir}
    cp usr/lib/systemd/system-preset/* %{buildroot}/%{_unitdir}/../system-preset
    pushd %{buildroot}/%{_sbindir}
    ln -s service rcgoogle
    ln -s service rcgoogle-startup-scripts
    ln -s service rcgoogle-shutdown-scripts
    popd
    %if 0%{?suse_version} > 1220
        cp -r lib/udev %{buildroot}/usr/lib
    %else
        cp -r lib/udev %{buildroot}/lib
    %endif
%else
    %{__mkdir} -p %{buildroot}/%{_initrddir}
    %{__mkdir} -p %{buildroot}/%{_sbindir}
    %{__mkdir} -p %{buildroot}/lib
    cp -r lib/udev %{buildroot}/lib
    cp %{SOURCE1} %{buildroot}/%{_initrddir}/google
    cp %{SOURCE2} %{buildroot}/%{_initrddir}/google-startup-scripts
    ln -s ../../%{_initrddir}/google %{buildroot}%{_sbindir}/rcgoogle
    ln -s ../../%{_initrddir}/google-startup-scripts %{buildroot}%{_sbindir}/rcgoogle-startup-scripts
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%preun
%if 0%{?suse_version} > 1140
    %service_del_preun google.service
    %service_del_preun google-startup-scripts.service
    %service_del_preun google-shutdown-scripts.service
%else
    %stop_on_removal
%endif

%pre
%if 0%{?suse_version} > 1140
    %service_add_pre google.service
    %service_add_pre google-startup-scripts.service
    %service_add_pre google-shutdown-scripts.service
%endif

%post
%if 0%{?suse_version} > 1140
    %service_add_post google.service
    %service_add_post google-startup-scripts.service
    %service_add_post google-shutdown-scripts.service
%endif

%postun
%if 0%{?suse_version} > 1140
    %service_del_postun google.service
    %service_del_postun google-startup-scripts.service
    %service_del_postun google-shutdown-scripts.service
%else
    %insserv_cleanup
%endif

%files
%defattr(-,root,root,-)
%doc LICENSE
%{_datadir}/google/*
%{_sbindir}/rcgoogle
%{_sbindir}/rcgoogle-startup-scripts
%dir %{_datadir}/google
%dir %{_datadir}/google/boto
%dir /etc/rsyslog.d
%if 0%{?suse_version} > 1140
%{_sbindir}/rcgoogle-shutdown-scripts
%{_unitdir}/google.service
%{_unitdir}/google-startup-scripts.service
%{_unitdir}/google-shutdown-scripts.service
%{_unitdir}/../system-preset/50-google.preset
%else
%attr(0755,root,root) %{_initrddir}/google
%attr(0755,root,root) %{_initrddir}/google-startup-scripts
%dir /lib/udev
%dir /lib/udev/rules.d
%dir %{_sysconfdir}/sysctl.d
%endif
%if 0%{?suse_version} > 1220
/usr/lib/udev/rules.d/*
%else
/lib/udev/rules.d/*
%endif
%config %{_sysconfdir}/rsyslog.d/90-google.conf
%config %{_sysconfdir}/sysctl.d/11-gce-network-security.conf

%changelog
* Thu Nov  3 2016 lchiquitto@suse.de
- Add pkgconfig(udev) to BuildRequires list to fix building on
  SUSE:SLE-12:Update
* Wed Feb 17 2016 rjschwei@suse.com
- Add regenhostkey_usetmpdir.diff (bsc#965896)
* Sat Feb 13 2016 rjschwei@suse.com
- Update to version 1.3.2 (bsc#966582, bsc#966583)
  + Provide a shutdown service for systemd based systems to better
    controll the order
* Thu Jan 28 2016 rjschwei@suse.com
- Update to version 1.3.1 (bsc#963879,bsc#963880)
  + Fix Ubuntu 15.x and RHEL/CentOS 7 shutdown scripts timing out after
    about 90 seconds.
* Mon Nov 23 2015 rjschwei@suse.com
- Update to version 1.2.10 (bsc#956339,bsc#956340)
  + Fix for metadata scripts at a redirected URL
* Mon Aug  3 2015 jgleissner@suse.com
- Update to version 1.2.7 (bnc#940190)
  + Add systemd support for restarting SSH after key generation.
  + Update safe_format_and_mount
- google-startup-scripts_disable_console_log.diff: Removed rsyslogd
  configuration that sends kernel and other messages to console
  (bnc#939272)
* Wed Mar 11 2015 rjschwei@suse.com
- Update to version 1.2.4 (bnc#921732)
  + Check for a connection to the metadata server before startup
    script retrieval.
  + Block startup scripts until a connection to the metadata server exists.
  + Added logging for network connectivity issues.
  + Added retry logic in startup scripts for metadata requests.
  + Improved performance on local SSD.
  + Fix a bug which could cause instances to take 2 minutes to shut down.
  + Miscellaneous documentation and diagnostic updates.
  + Ensured that shutdown script feature will run before docker and kubelet.
* Fri Nov 14 2014 rschweikert@suse.com
- Update to version 1.1.9  bnc#905571
  + resolve version inconsistency
  + Added a logging file for the shutdown script feature.
  + Improvements allowing the startup scripts to work as intended on
    RHEL 7 and CentOS 7.
  + Removed explicit run of apt-get update at first boot on Debian-based systems
  + Improved first-boot SSH host key regeneration
  + Improvements to shutdown script feature
  + Fix for first-boot script which was failing to run fully
  + Basic support for shutdown scripts on all supported distros (experimental)
  + safe_format_and_mount now works on RHEL 6
  + Improve ordering on systemd systems
  + Add rc* links for distros > 1140
* Wed Sep 24 2014 rschweikert@suse.com
- fix start up scripts, should not list run level 4, it generates
  a message
* Mon Jul 28 2014 rschweikert@suse.com
- Bump to version 1.1.8 -> corresponds to upstream 1.1.5
  + version inconsistency due to previous use of git repo integration and
    subsequent version bumps for the package
  + removed redundant authentication check
  + startup scripts now support newer Google Cloud Storage URIs
* Tue Jul  1 2014 rschweikert@suse.com
- Bump to version 1.1.7 -> corresponds to upstream 1.1.4
  + version inconsistency due to previous use of git repo integration and
    subsequent version bumps for the package
  + Update get_metadata_value to use v1 metadata server url for instance
    with fallback to project.
* Wed Jun  4 2014 rschweikert@suse.com
- Bump version to 1.1.6 -> corresponds to upstream 1.1.3
  + version inconsistency due to previous use of git repo integration and
    subsequent version bumps for the package
  + no upstream change log, nor decent commit messages that separate
    changes to this code bases vs. other code in the same repo
* Wed May 21 2014 jsegitz@novell.com
- added necessary macros for systemd files
* Wed Feb 19 2014 rschweikert@suse.com
- Include in SLE 12 (FATE #316168)
- Bump version to 1.1.5 -> corresponds to upstream 1.1.1
  + version inconsistency due to previous use of git repo integration and
    subsequent version bumps for the package
  + Improved systemd integration.
  + Startup scripts in the guest are now downloaded with Curl instead of Wget.
  >>>>>>> ./google-startup-scripts.changes.r7
* Fri Dec  6 2013 rschweikert@suse.com
- update to 1.1.4
  + support multi-queue for virtionet devices
* Wed Nov 20 2013 rschweikert@suse.com
- update to 1.0.10 rc2
* Thu Nov  7 2013 rschweikert@suse.com
- fix redirection in startup script
- look in /usr/bin first for the logger
* Fri Nov  1 2013 rschweikert@suse.com
- update to 1.0.9 pre cursor to next release 1.0.10
  + include fix for bash IO redirect operator
  + include fix for location of logger executable
- fix executable bits of init scripts
* Thu Oct 31 2013 rschweikert@suse.com
- update to version 1.0.7.1
  + add .1 postfix as the 1.0.7 upstream tarball does not contain my
    systemd changes yet
- implement SUSE specific init scripts
- remove the gcestartup_stopTarget.patch as it is no longer needed
- spec file clean up
* Fri Oct 11 2013 rschweikert@suse.com
- fix build errors for 12.2 and SLE
  + fix up of locations between / and /usr
  + add patch gcestartup_stopTarget.patch to fixup init scripts
* Thu Oct 10 2013 rschweikert@suse.com
- Initial build
